<?php
/** Kongo (Kongo)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Rkupsala
 * @author לערי ריינהארט
 */

$namespaceNames = array(
	NS_TALK             => 'Disolo',
	NS_USER             => 'Kisadi',
	NS_USER_TALK        => 'Disolo_kisadi',
	NS_PROJECT_TALK     => 'Disolo_$1',
	NS_FILE             => 'Fisye',
	NS_FILE_TALK        => 'Disolo_fisye',
	NS_HELP             => 'Lusadisu',
	NS_HELP_TALK        => 'Disolo_lusadisu',
	NS_CATEGORY         => 'Kalasi',
	NS_CATEGORY_TALK    => 'Disolo_kalasi',
);

$messages = array(
'underline-always' => 'Bambala nyonso',
'underline-never' => 'Ata mbala mosi ve',

# Dates
'sunday' => 'Lumîngu',
'monday' => 'Kimosi',
'tuesday' => 'Kizôle',
'wednesday' => 'Kitatu',
'thursday' => 'Kîya',
'friday' => 'Kitânu',
'saturday' => 'Sabala',
'sun' => 'Lum',
'mon' => 'ki-1',
'tue' => 'ki-2',
'wed' => 'ki-3',
'thu' => 'ki-4',
'fri' => 'ki-5',
'sat' => 'Sab',
'january' => 'ngônda ya ntete',
'february' => 'ngônda ya zôle',
'march' => 'ngônda ya tatu',
'april' => 'ngônda ya yiya',
'may_long' => 'ngônda ya tânu',
'june' => 'ngônda ya sambânu',
'july' => 'ngônda ya nsambwâdi',
'august' => 'ngônda ya nâna',
'september' => 'ngônda ya yivwa',
'october' => 'ngônda ya kûmi',
'november' => 'ngônda ya kûmi na mosi',
'december' => 'ngôida ya kûmi na zôle',
'january-gen' => 'ngônda ya ntete',
'february-gen' => 'ngônda ya zôle',
'march-gen' => 'ngônda ya tatu',
'april-gen' => 'ngônda ya yiya',
'may-gen' => 'ngônda ya tânu',
'june-gen' => 'ngônda ya sambânu',
'july-gen' => 'ngônda ya nsambwâdi',
'august-gen' => 'ngônda ya nâna',
'september-gen' => 'ngônda ya yivwa',
'october-gen' => 'ngônda ya kûmi',
'november-gen' => 'ngônda ya kûmi na mosi',
'december-gen' => 'ngônda ya kûmi na zôle',
'jan' => 'ng1',
'feb' => 'ng2',
'mar' => 'ng3',
'apr' => 'ng4',
'may' => 'ng5',
'jun' => 'ng6',
'jul' => 'ng7',
'aug' => 'ng8',
'sep' => 'ng9',
'oct' => 'ng10',
'nov' => 'ng11',
'dec' => 'ng12',

# Categories related messages
'pagecategories' => '{{PLURAL:$1|Kalasi|Bakalasi}}',
'category_header' => 'Mikanda na kalasi "$1"',

'article' => 'Pagina contenta continens',
'cancel' => 'Katula',
'mypage' => 'Lukaya ya munu',
'mytalk' => 'Disolo ya munu',
'and' => '&#32;mpe',

# Cologne Blue skin
'qbfind' => 'Sosa',
'qbbrowse' => 'Tala',
'qbedit' => 'Soba',

# Vector skin
'vector-action-delete' => 'Kufwa',
'vector-action-move' => 'Nata',
'vector-view-edit' => 'Sonika',
'vector-view-history' => 'Tala bansoba',
'vector-view-view' => 'Tânga',

'errorpagetitle' => 'Foti',
'returnto' => 'Vutukila $1',
'help' => 'Nsadisa',
'search' => 'Sosa',
'searchbutton' => 'Sosa',
'searcharticle' => 'Kwenda',
'history' => 'Bansoba ya mukanda',
'history_short' => 'Bansoba',
'view' => 'Tala',
'edit' => 'Sonika',
'editthispage' => 'Soba mukanda yayi',
'delete' => 'Kufwa',
'deletethispage' => 'Kufwa mukanda yayi',
'talkpagelinktext' => 'Disolo',
'talk' => 'Disolo',
'views' => 'Bantadilu',
'toolbox' => 'Bisadilu',
'viewtalkpage' => 'Tala disolo',
'otherlanguages' => 'Bandinga ya nkaka',
'redirectedfrom' => '(Balulama tuka $1)',
'lastmodifiedat' => 'Mukânda yayi me sobama na kilumbu $1 na ngûnga $2',
'jumpto' => 'Pamuka na:',
'jumptosearch' => 'nsosa',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents' => 'Mambu ya mpa',
'currentevents-url' => 'Project:Mambu ya mpa',
'mainpage' => 'Lukaya ya mfumu',
'mainpage-description' => 'Lukaya ya mfumu',

'retrievedfrom' => 'Receptum de "$1"',
'youhavenewmessages' => 'Nge kele na $1 ($2).',
'newmessageslink' => 'bansangu ya yimpa',
'youhavenewmessagesmulti' => 'Nge kele na bansangu ya yimpa kuna $1',
'editsection' => 'soba',
'editold' => 'soba',
'editlink' => 'soba',
'editsectionhint' => 'Soba kibuku: $1',
'red-link-title' => '$1 (mukanda kele ve)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Mukanda',
'nstab-mediawiki' => 'Nsangu',
'nstab-category' => 'Kalasi',

# Login and logout pages
'yourname' => 'Nkûmbu ya nsoniki:',
'yourpassword' => 'Mpovo ya kuluta:',
'login' => 'Kota',
'userlogin' => 'Kota / sala konti',
'logout' => 'Basika',
'userlogout' => 'Basika',
'nologin' => 'Nge kele na konti ve? $1.',
'nologinlink' => 'Sala konti',
'createaccount' => 'Sala konti',
'gotaccountlink' => 'Kota',
'loginlanguagelabel' => 'Ndinga: $1',

# Edit pages
'newarticle' => '(Yimpa)',
'editing' => 'Na kusonika $1',
'editingsection' => 'Na kusonika $1 (kibuku)',

# History pages
'history-fieldset-title' => 'Monisa bansoba',
'histfirst' => 'Ya ntete',
'histlast' => 'Ya nsuka',

# Diffs
'lineno' => 'Nzila ya $1:',
'editundo' => 'vutula',

# Search results
'prevn' => 'biyita {{PLURAL:$1|$1}}',
'nextn' => 'bilandi {{PLURAL:$1|$1}}',
'viewprevnext' => 'Mona ($1 {{int:pipe-separator}} $2) ($3).',
'searchprofile-everything' => 'Nyonso',
'searchprofile-articles-tooltip' => 'Sosa na $1',
'searchprofile-project-tooltip' => 'Sosa na $1',
'search-result-size' => '$1 ({{PLURAL:$2|mpovo 1|bampovo $2}})',
'search-section' => '(kibuku $1)',
'searchall' => 'nyonso',
'powersearch' => 'Sosa',

# Preferences page
'mypreferences' => 'Konte ya munu',
'yourlanguage' => 'Ndinga:',

# Recent changes
'recentchanges' => 'Bansoba ya yimpa',
'recentchanges-label-minor' => 'Nsoba yayi kele ya fyoti-fyoti',
'recentchanges-label-bot' => 'Nsoba yayi me salama na robo',
'rcshowhideminor' => '$1 bansoba ya fyoti-fyoti',
'rcshowhidemine' => '$1 bansoba na munu',
'diff' => 'nsoba',
'hist' => 'nsoba',
'show' => 'Monisa',
'minoreditletter' => 'f',

# File description page
'filehist-datetime' => 'Kilumbu/Ngûnga',
'filehist-user' => 'Nsoniki',

# Random page
'randompage' => 'Lukaya na kintulumukini',

# Miscellaneous special pages
'ncategories' => '{{PLURAL:$1|kalasi|bakalasi}} $1',
'newpages' => 'Mikanda ya yimpa',

# Special:AllPages
'alphaindexline' => '$1 tî $2',

# Special:Categories
'categories' => 'Bakalasi',

# Contributions
'mycontris' => 'Makabu ya munu',
'month' => 'Katuka ngônda:',
'year' => 'Katuka mvula:',

'sp-contributions-talk' => 'disolo',

# What links here
'whatlinkshere' => 'Balukaya ke songa awa',

# Move page
'movearticle' => 'Nata lukaya:',
'newtitle' => 'Nkûmbu ya nkaka:',
'movepagebtn' => 'Nata lukaya',
'pagemovedsub' => 'Kunata me nunga',
'movepage-moved' => '\'\'\'"$1" me natama na "$2"\'\'\'',
'articleexists' => 'Lukaya ya nkaka kele na nkûmbu yango, to nkûmbu yango kele ya mbote ve.
Sôla nkûmbu ya nkaka.',
'movereason' => 'Samu:',

# Tooltip help for the actions
'tooltip-pt-userpage' => 'Mukanda ya munu',
'tooltip-pt-mytalk' => 'Disolo ya munu',
'tooltip-pt-logout' => 'Basika',
'tooltip-search' => 'Sosa na {{SITENAME}}',
'tooltip-undo' => '"Vutula" ke vutula nsoba yayi mpe yawu ke monisa lumoni ya kusoba. Nge lênda sonika kikuma ya mvutula.',

# 'all' in various places, this might be different for inflected languages
'namespacesall' => 'nyonso',
'monthsall' => 'nyonso',

# Table pager
'table_pager_next' => 'Lukaya ya kulanda',
'table_pager_prev' => 'Lukaya ya kuyita',
'table_pager_first' => 'Lukaya ya ntete',
'table_pager_last' => 'Lukaya ya nsuka',

);
